# Table of Contents

- [erp-transformation](<./erp-transformation.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [ERP Transformation](<./ERP-Transformation.md>)
  - [Overview](<./ERP-Transformation/Overview.md>)
  - [What Does ERP Transformation Mean?](<./ERP-Transformation/What-Does-ERP-Transformation-Mean.md>)
  - [Reasons to Start an ERP Transformation](<./ERP-Transformation/Reasons-to-Start-an-ERP-Transformation.md>)
  - [Why Do Organizations Struggle with ERP Transformations?](<./ERP-Transformation/Why-Do-Organizations-Struggle-with-ERP-Transformations.md>)
  - [Benefits of ERP Transformation with SAP LeanIX](<./ERP-Transformation/Benefits-of-ERP-Transformation-with-SAP-LeanIX.md>)
  - [Benefits for Different Stakeholders](<./ERP-Transformation/Benefits-for-Different-Stakeholders.md>)
  - [Which SAP LeanIX Products Are Needed for ERP Transformation?](<./ERP-Transformation/Which-SAP-LeanIX-Products-Are-Needed-for-ERP-Transformation.md>)
  - [How to Support ERP Transformation with SAP LeanIX?](<./ERP-Transformation/How-to-Support-ERP-Transformation-with-SAP-LeanIX.md>)
